==> benchling-api-client-1.1.0a2.tar.gz: benchling-api-client-1.1.0a2/benchling_api_client/v2/stable/models/fields.py <==
from typing import Any, Dict, List, Optional, Type, TypeVar

import attr

from ..models.field import Field

T = TypeVar("T", bound="Fields")


@attr.s(auto_attribs=True, repr=False)
class Fields:
    """  """

    additional_properties: Dict[str, Field] = attr.ib(init=False, factory=dict)

    def __repr__(self):
        fields = []
        fields.append("additional_properties={}".format(repr(self.additional_properties)))
        return "Fields({})".format(", ".join(fields))

    def to_dict(self) -> Dict[str, Any]:

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        fields = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = Field.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        fields.additional_properties = additional_properties
        return fields

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Field:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Field) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def get(self, key, default=None) -> Optional[Field]:
        return self.additional_properties.get(key, default)

==> benchling-api-client-2.0.93.tar.gz: benchling-api-client-2.0.93/benchling_api_client/v2/stable/models/fields.py <==
from typing import Any, Dict, List, Optional, Type, TypeVar

import attr

from ..models.field import Field

T = TypeVar("T", bound="Fields")


@attr.s(auto_attribs=True, repr=False)
class Fields:
    """  """

    additional_properties: Dict[str, Field] = attr.ib(init=False, factory=dict)

    def __repr__(self):
        fields = []
        fields.append("additional_properties={}".format(repr(self.additional_properties)))
        return "Fields({})".format(", ".join(fields))

    def to_dict(self) -> Dict[str, Any]:

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
        d = src_dict.copy()

        fields = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = Field.from_dict(prop_dict, strict=False)

            additional_properties[prop_name] = additional_property

        fields.additional_properties = additional_properties
        return fields

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Field:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Field) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def get(self, key, default=None) -> Optional[Field]:
        return self.additional_properties.get(key, default)
